@@ -1,14 +1,18 @@
+import pytest
 from django.urls import path
-from rest_framework import serializers, viewsets, mixins, routers
-from rest_framework_simplejwt.authentication import JWTAuthentication
-from rest_framework_simplejwt.views import (
-    TokenObtainPairView,
-    TokenRefreshView,
-)
+from rest_framework import mixins, routers, serializers, viewsets
 
-from drf_spectacular.openapi import SchemaGenerator
+from drf_spectacular.generators import SchemaGenerator
 from tests import assert_schema
 
+try:
+    from rest_framework_simplejwt.authentication import JWTAuthentication
+    from rest_framework_simplejwt.views import (
+        TokenObtainPairView, TokenObtainSlidingView, TokenRefreshView,
+    )
+except ImportError:
+    JWTAuthentication = None
+
 
 class XSerializer(serializers.Serializer):
     uuid = serializers.UUIDField()
@@ -20,6 +24,7 @@ class XViewset(mixins.ListModelMixin, viewsets.GenericViewSet):
     required_scopes = ['x:read', 'x:write']
 
 
+@pytest.mark.contrib('rest_framework_simplejwt')
 def test_simplejwt(no_warnings):
     router = routers.SimpleRouter()
     router.register('x', XViewset, basename="x")
@@ -27,6 +32,7 @@ def test_simplejwt(no_warnings):
     urlpatterns = [
         *router.urls,
         path('token/', TokenObtainPairView.as_view(), name='token_obtain_pair'),
+        path('token-sliding/', TokenObtainSlidingView.as_view(), name='token_obtain_sliding'),
         path('token/refresh/', TokenRefreshView.as_view(), name='token_refresh'),
     ]
 
